# Metadatensatz

Metadaten sind ein zentraler Bestandteil einer Einreichung. Sie beschreiben die Struktur der Einreichung und dessen
Inhalte, wie beispielsweise Anlagen oder die Fachdaten. Zusätzlich können weitere Informationen über d:ie Verwaltungskund:in
hinterlegt werden. Eine genaue Definition ist in der [Schema-Definition](../apis/metadata.mdx)
zu finden. Im Folgenden werden nun die großen Bereiche, die im Metadatenschema aufgeführt werden, grob beschrieben.

Das Metadaten-Schema validiert gegen und orientiert sich an der [JSON Schema Spezifikation 2020-12](https://json-schema.org/specification-links.html#2020-12)
in der Version von 2020. Es besteht primär aus den fünf Bereichen Authentifizierungsinformationen, Inhaltsstruktur,
Bezahlinformationen, Verwaltungsleistung und Rückkanal.

```json
{
  "authenticationInformation": [
    …
  ],
  "paymentInformation": {
    …
  },
  "publicServiceType": {
    …
  },
  "contentStructure": {
    …
  },
  "replyChannel": {
    …
  }
}
```

## Authentifizierungsinformationen (`authenticationInformation`)

In den Authentifizierungsinformationen wird eine Liste aller Identifikationsnachweise hinterlegt, die für die
Einreichung notwendig sind. Die Identifikationsnachweise können dabei unterschiedliche Typen innehaben, wie
beispielsweise ein `IdentficationReport` durch eID oder eine Bestätigung durch Elster.

```json
{
  "authenticationInformation": [
    {
      "type": "identificationReport",
      "content": "aGVsbG8gd29ybGQ="
    },
    {
      "type": "identificationReport",
      "content": "UGVyc29uYWxhdXN3ZWlzCg=="
    }
  ]
}
```

## Inhaltsstruktur (`contentStructure`)

Im Objekt der Inhaltsstruktur werden alle zusätzlichen Inhalte, die zu der Einreichung gehören, wie Anlagen oder
Fachdaten, beschrieben.

```json
{
  ...,
  "contentStructure": {
    "data": {
      "schema": {
        "schemaURI": "urn:de:fim:leika:leistung:99015004037000",
        "mimeType": "application/json"
      }
    },
    "attachments": [
      {
        "filename": "file_91571892B610A9E3556491BCC6844BAD582.jpg",
        "purpose": "attachment",
        "attachmentId": "82050376-a506-4d25-8fad-ebfbb74e2f10",
        "description": "Passbild (F99000582)",
        "mimeType": "image/jpeg"
      },
      {
        "filename": "file_403672D5970CD33C9E0AE12D2B38FE07393.png",
        "purpose": "attachment",
        "attachmentId": "45413e64-6635-4836-a46f-162e5abe6731",
        "description": "Nachweis über vorherige Antragsstellungen bei Berufsgenossenschaften oder Behörden (G03000159.G03000161.G03000158.F99000393)",
        "mimeType": "image/png"
      },
      {
        "filename": "file_846E243838246ADCD66E4372EE60616D374.pdf",
        "purpose": "attachment",
        "attachmentId": "36a6f99b-b251-40b3-b20f-d32af8108351",
        "description": "Nachweis/Kopie Unterschriebene Schweigepflichtsentbindung (G03000221.G99000373.F99000374)",
        "mimeType": "application/pdf",
        "signature": {
          "type": "pdf"
        }
      },
      {
        "filename": "print.pdf",
        "purpose": "form",
        "attachmentId": "653dc130-305d-49a7-983f-c757e37f820a",
        "description": "Antragsformular",
        "mimeType": "application/pdf",
        "signature": {
          "type": "pdf-detached",
          "content": "TG9yZW1JcHN1bVNpbmVEb2xvckFtZXRIaXBzZXIgU2F5IFdPT1AgQk9PUGJpQmFtCg=="
        }
      },
      {
        "filename": "deckblatt.pdf",
        "purpose": "report",
        "attachmentId": "383cc3e6-9c9b-41fb-a8e7-57160197ac3d",
        "description": "Deckblatt mit Antrags-Metadaten",
        "mimeType": "application/pdf"
      }
    ]
  },
  ...
}
```

## Bezahlinformationen (`paymentInformation`)

Dieses Objekt enthält die Bezahlinformationen, die von einem Onlineservice an den Zustellpunkt übergeben werden sollen.
Darin sind Informationen zur Rechnungsstellung zu finden, sowie Informationen über den Bezahlvorgang, falls er über einen
externen Bezahldienstleister abgewickelt wurde.

Die Bezahlinformationen sind ein optionales Feld und die Bedeutung fehlender Bezahlinformation ist, dass d:er Verwaltungskund:in
die Leistung noch in Rechnung gestellt werden muss oder die Leistung kostenfrei ist.

```json
{
  ...,
  "paymentInformation": {
    "transactionUrl": "https://payment.bundesland.zzzz/api/v1/paymenttransaction/12002312/MELD-ANT-FORM-4711/2ec6dad2-5606-4a85-82bc-19521ed5e192",
    "transactionReference": "KA-2021-5678",
    "transactionId": "2ec6dcc2-5606-4a95-82bc-19521fd5e192",
    "paymentMethod": "GIROPAY",
    "status": "BOOKED",
    "grossAmount": 15.00
  },
  ...
}
```

## Verwaltungsleistung (`publicServiceType`)

Beschreibung der Art der Verwaltungsleistung. Eine Verwaltungsleistung sollte immer mit einer LeiKa-Id beschrieben
werden. Ist für die gegebene Verwaltungsleistung keine LeiKa-Id vorhanden, kann die Verwaltungsleistung übergangsweise
über die Angabe eines Schemas (`otherIdentifiers`) beschrieben werden.

```json
{
  ...,
  "publicServiceType": {
    "identifier": "urn:de:fjd:s03000025",
    "name": "Antrag auf Feststellung einer Behinderung und Zuerkennung von Merkzeichen",
    "description": "Menschen, die körperliche, seelische, geistige oder Sinnesbeeinträchtigungen haben, die sie über mindestens 6 Monate an der gleichberechtigten Teilhabe an der Gesellschaft hindern, können einen Antrag auf Feststellung einer Behinderung nach dem Sozialgesetzbuch - Neuntes Buch (SGB IX ) stellen. Das Landesamt für Soziales, Jugend und Familie prüft den Grad der Behinderung (GdB) und erteilt ab einem GdB von 20 einen Feststellungsbescheid. Als Nachweis der Behinderung kann dann ein Schwerbehindertenausweis ausgestellt werden. Dieser wird ausgestellt, wenn der festgestellte GdB wenigstens 50 beträgt. Werden zudem bestimmte gesundheitliche Merkmale festgestellt (z.B. Blindheit, Hör- oder Bewegungseinschränkungen) können Merkzeichen in den Schwerbehindertenausweis eingetragen werden. Diese Merkzeichen berechtigen zur Inanspruchnahme von Nachteilsausgleichen zum Beispiel steuerliche Vorteile oder unentgeltliche Beförderung mit Bus und Bahn und werden im Schwerbehindertenausweis mit aufgeführt. \r\n\r\nFür die Antragsstellung benötigen Sie Informationen zur betroffenen Person sowie ggf. zu vertretenden Personen, die den Antrag stellvertretend für die betroffene Person stellen. Für die Bearbeitung sind im Weiteren Informationen zu bisherigen Antragsstellungen auf Feststellung einer Behinderung, Rentenanträge, Pflegegrade sowie dauerhafte gesundheitliche Beeinträchtigungen und ärztliche Behandlungen erforderlich. Nähere Informationen können Sie dem beigefügten [Merkblatt zum Antrag nach dem Sozialgesetzbuch - Neuntes Buch - SGB IX (PDF)](https://soziales.niedersachsen.de/download/160332/Merkblatt_zum_Antrag_nach_dem_Sozialgesetzbuch_-_Neuntes_Buch_-_SGB_IX_.pdf \"Merkblatt zum Antrag nach dem Sozialgesetzbuch - Neuntes Buch - SGB IX (PDF, externe Seite)\") entnehmen.\r\n\r\nÜber die Online-Ausweisfunktion Ihres Personalausweises können Sie sich im Laufe des Antrags außerdem digital ausweisen. Hierfür können Sie den neuen Personalausweis, der einen Chip enthält und die Identifikation im Internet sicherstellen kann, verwenden.\r\n\r\n\r\n* Ihren Personalausweis mit eingeschalteter Online-Ausweisfunktion\r\n* Ihre 6-stellige PIN\r\n* Ein geeignetes Smartphone oder einen Kartenleser  \r\n* Die AusweisApp des Bundes\r\n\r\nWeitere Informationen zur AusweisApp finden Sie auf der [Homepage der AusweisApp](https://www.ausweisapp.bund.de/ausweisapp2/ \"Homepage der AusweisApp (externe Seite)\").\r\n\r\n**Sie haben die Möglichkeit Anlagen im Antrag hochzuladen oder in Kopie an die Zentrale Postanschrift des Niedersächsischen Landesamt für Soziales, Jugend und Familie in 31120 Hildesheim übersenden. Bitte versehen Sie Ihre Unterlagen beim Versenden per Post mit Ihrem Aktenzeichen und übersenden Sie bis auf Fotos bitte nur Fotokopien und keine Originale, da diese im Zuge der Digitalisierung vernichtet werden.**"
  },
  ...
}
```

## Rückkanal (`replyChannel`)

Der Rückkanal beschreibt einen Kommunikationskanal, um zwischen der zuständigen Stelle und d:er Verwaltungskund:in digital zu kommunizieren.
Eine zuständige Stelle kommuniziert über den Zustellpunkt, welche Kommunikationskanäle unterstützt werden und
d:ie Verwaltungskund:in wählt einen gewünschten Kommunikationskanal daraus heraus.

Für die Adressierung d:er Autor:in werden alle für den Kommunikationskanal notwendigen Verbindungs- und Adressparameter
(einschließlich ggf. notwendiger Schlüssel/Zertifikate) im Metadatensatz mitgeliefert.

```json
{
  "type": "object",
  "minProperties": 1,
  "properties": {
    "eMail": {
      "type": "object",
      "properties": {
        "address": {
          "type": "string",
          "format": "email"
        },
        "pgpPublicKey": {
          "type": "string",
          "description": "Hilfe zur Erstellung gibt es in der Dokumentation unter TODO.",
          "pattern": "^-----BEGIN PGP PUBLIC KEY BLOCK-----\\n\\n"
        }
      },
      "required": [
        "address"
      ]
    },
    "deMail": {
      "type": "object",
      "description": "Akkreditierte Anbieter siehe https://www.bsi.bund.de/DE/Themen/Oeffentliche-Verwaltung/Moderner-Staat/De-Mail/Akkreditierte-DMDA/akkreditierte-dmda_node.html",
      "properties": {
        "address": {
          "type": "string",
          "format": "email"
        }
      },
      "required": [
        "address"
      ]
    },
    "fink": {
      "type": "object",
      "description": "Postfachadresse in einem interoperablen Servicekonto (FINK.PFISK)",
      "properties": {
        "finkPostfachRef": {
          "type": "string",
          "description": "FINK Postfachadresse",
          "examples": [
            "hh/by/12345"
          ],
          "maxLength": 150,
          "pattern": "^[-._a-z0-9~\/]*$"
        },
        "host": {
          "type": "string",
          "description": "URL des Servicekontos, in dem das Ziel-Postfach liegt",
          "format": "uri",
          "examples": [
            "https://servicekonto1.example.com/"
          ]
        }
      },
      "required": [
        "finkPostfachRef"
      ]
    },
    "elster": {
      "type": "object",
      "description": "Siehe https://www.elster.de/elsterweb/infoseite/elstertransfer_hilfe_schnittstellen",
      "properties": {
        "accountId": {
          "type": "string",
          "pattern": "^\\d{10}$"
        },
        "lieferTicket": {
          "type": "string"
        },
        "geschaeftszeichen": {
          "type": "string",
          "maxLength": 10
        }
      },
      "required": [
        "accountId"
      ]
    }
  }
}
```

## Zusätzliche Informationen (`additionalReferenceInfo`)

In diesem Objekt können zusätzliche Informationen, eine Einreichung betreffend hinterlegt werden. Spezifizierte
Möglichkeiten sind Informationen, wie Informationen zum Sender (`senderReference`) oder das Versanddatum (`submissionDate`) der Einreichung
aufseiten des sendenden Systems. Allerdings können hier noch weitere eigene Informationen hinterlegt bzw. mitgesendet werden,
die jedoch nicht automatisch von einem empfangenden System genutzt werden müssen.
